@@ -426,7 +426,7 @@ namespace mongo {
         BSONObj startKey = min;
         for ( vector<BSONObj>::const_iterator it = splitKeys.begin() ; it != splitKeys.end() ; ++it ) {
             BSONObj split = *it;
-            p->_chunksMap[min] = split.getOwned();
+            p->_chunksMap[startKey] = split.getOwned();
             p->_chunksMap.insert( make_pair( split.getOwned() , max.getOwned() ) );
             p->_version.incMinor();
             startKey = split;
